%-------------------------------------------------------------------------%
%        THE WITHIN-COUNTRY DISTRIBUTION OF BRAIN DRAIN AND BRAIN         %
%                   GAIN EFFECTS: A CASE STUDY ON SENEGAL                 %
%                   Journal of Demograhic Economics (2024)                %
%                               Authors :                                 %
%           Bocquier P., Cha'ngom N., Docquier F., and Machado J.         %
%-------------------------------------------------------------------------%


%-------------------------------------------------------------------------%
%                             01 - UPLOAD DATA                            %
%-------------------------------------------------------------------------%
deptodep = readtable('JODE_data_calib.csv','Headerlines',0,'ReadVariableNames',true);
deptodep = sortrows(deptodep,{'ori','des'});

%-------------------------------------------------------------------------%
%                            02 - PREPARE VECTORS                         %
%-------------------------------------------------------------------------%

%%%%%%%%%%%%%%%%%%%%%%% VARIABLES EXTRACTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T = height(deptodep);
dumst = deptodep.dmstay;
Mij = (1-dumst).*deptodep.Mij; MijH = (1-dumst).*deptodep.MijHS;  MijL = (1-dumst).*deptodep.MijLS;  
Li = deptodep.Li; Lih = deptodep.LiH; Lil = deptodep.LiL;
Nii = deptodep.Nii; Niih = deptodep.Niih; Niil = deptodep.Niil;
Ni = deptodep.Ni; Nih = deptodep.Nih; Nil = deptodep.Nil;
Lj = deptodep.Lj; Ljh = deptodep.LjH; Ljl = deptodep.LjL;
Hri = deptodep.Hr_i; Hrj = deptodep.Hr_j; Hni = deptodep.Hn_i;
wHi = deptodep.wH_i; wLi = deptodep.wL_i;wi = deptodep.w_i;
wHj = deptodep.wH_j; wLj = deptodep.wL_j; wj = deptodep.w_j;
remi = deptodep.remittances_i;
cijhNMa = deptodep.cijhNMa; cijlNMa = deptodep.cijlNMa; cijhNIMa = deptodep.cijhNIMa; cijlNIMa = deptodep.cijlNIMa; % this eases the setup of counterfactuals exercises 
cijhNoecdMa = deptodep.cijhNoecdMa; cijlNoecdMa = deptodep.cijlNoecdMa; cijhNdkMa = deptodep.cijhNdkMa; cijlNdkMa = deptodep.cijlNdkMa; % Idem 
i = deptodep.ori; j = deptodep.des; 
o_iso = deptodep.o_iso; 

%-------------------------------------------------------------------------%
%                    03 - SET EXOGENOUS PARAMETERS                        %
%-------------------------------------------------------------------------%
mu = .7; % EVT1-shape parameter (inverse of the income elasticity of migration
zstar = 3.2; % indicate the way migration governs education incentives


%-------------------------------------------------------------------------%
%                    04 - INFER BILATERAL MIGRATION COST                  %
%-------------------------------------------------------------------------%

cijh = 1 - ((wHi./wHj).*(MijH./Niih).^mu);
cijl = 1 - ((wLi./wLj).*(MijL./Niil).^mu);

%-------------------------------------------------------------------------%
%                     05 -  ATTARCTIVNESS  OF DESTINATIONS                %
%-------------------------------------------------------------------------%

Wijh = (1-dumst).*(wHj.*(1-cijh)).^(1/mu);
Wijl = (1-dumst).*(wLj.*(1-cijl)).^(1/mu);
Wikh = (1-dumst).*((wHj./wHi).*(1-cijh)).^mu;
Wikl = (1-dumst).*((wLj./wLi).*(1-cijl)).^mu;

% Aggregation by origin location  and education premium
Attract = table(i,Wijh,Wijl,Wikh,Wikl);
SumAttract = varfun(@sum,Attract,"InputVariables",{'Wijh','Wijl','Wikh','Wikl'},"GroupingVariables",{'i'}); % sum across all destinations (j)
SumWijh = SumAttract.sum_Wijh; SumWijl =SumAttract.sum_Wijl;
SumWikh = 1+SumAttract.sum_Wikh; SumWikl = 1+SumAttract.sum_Wikl;

%-------------------------------------------------------------------------%
%                     06 -  INFER EDUCATION PREMIUM                       %
%-------------------------------------------------------------------------%
Ui = table(i,j,cijh,cijl);
i = SumAttract.i;
loc = table(i,SumWijh,SumWikh,SumWijl,SumWikl);
long = outerjoin(loc,Ui,'Type','left','Keys',{'i'},'MergeKeys',true);
long = sortrows(long,{'i','j'});
long.SumWijh = (1-dumst).*long.SumWijh;
long.SumWijl = (1-dumst).*long.SumWijl;
wH_exp = wHi.^(1/mu) + long.SumWijh;
wL_exp = wLi.^(1/mu) + long.SumWijl;
Lambda = wH_exp./wL_exp; 

%-------------------------------------------------------------------------%
%             07- ENDOGENIZED MIGRATION PROBABILITIES                     %
%                  AND PROVISION OF PUBLIC EDUCATION                      %
%-------------------------------------------------------------------------%

mH = (long.SumWijh)./wH_exp; 
mL = (long.SumWijl)./wL_exp; 
Gstar = (Lambda./(Lambda-1)).*Hni.^(1/(1+zstar)); 
Ratio = 1 - 1./Lambda; 
Hniendo = (Gstar.*Ratio).^(1+zstar); 
i = long.i;

%-------------------------------------------------------------------------%
%             08- ENDOGENIZED BILATERAL MIGRATION NUMBERS                 %
%-------------------------------------------------------------------------%

MijHendo = (1-dumst).*(((wHj./wHi).*(1-cijh)).^(1/mu)).*Niih; 
MijLendo = (1-dumst).*(((wLj./wLi).*(1-cijl)).^(1/mu)).*Niil; 
Nihendo = Ni.*Hniendo; Nilendo = Ni.*(1-Hniendo);
scatter(MijHendo,MijH)


%-------------------------------------------------------------------------%
%             09- ENDOGENIZED SIZE AND STRUCTURE OF THE LABOR FORCE       %
%-------------------------------------------------------------------------%

migdtaNew = table(i,j,MijHendo,MijLendo);
Emig = varfun(@sum,migdtaNew,"InputVariables",{'MijHendo','MijLendo'},"GroupingVariables",{'i'}); % sum across all destinations (j)
Emig = renamevars(Emig,["i","sum_MijHendo","sum_MijLendo"],["i1","EmH","EmL"]);
Emig.GroupCount=[] ; 
Emig.i1=[] ; 

migdtaNew = migdtaNew(migdtaNew.j < 144,:); % Ged rid of OECD destinations to make for immigrants numbers computations 
Imig = varfun(@sum,migdtaNew,"InputVariables",{'MijHendo','MijLendo'},"GroupingVariables",{'j'}); % sum across all origins (i)
Imig = renamevars(Imig,["j","sum_MijHendo","sum_MijLendo"],["i","ImH","ImL"]);
Imig.GroupCount=[] ; 
Sumendo =[Emig,Imig];
longMig = outerjoin(Sumendo,Ui,'Type','left','Keys',{'i'},'MergeKeys',true);
Niihendo = Nihendo-longMig.EmH; Niilendo = Nilendo-longMig.EmL;
Lihendo = Niihendo+longMig.ImH; Lilendo = Niilendo+longMig.ImL; 
Hriendo = Lihendo./(Lihendo+Lilendo);
scatter(Hniendo,Hriendo);
WelfareH = (1-dumst).*wH_exp; 
WelfareL = (1-dumst).*wL_exp;
%-------------------------------------------------------------------------%
%                     10- EXPORT INITIAL VALUES TO EXCEL                  %
%-------------------------------------------------------------------------%
% Export initial values to excel
ImH = longMig.ImH; ImL = longMig.ImL;EmH = longMig.EmH; EmL = longMig.EmL;
Init = table(i,o_iso,ImH,ImL,EmH,EmL,Nih,Nil,mH,mL,Lih,Lil,Hni,Hri,Gstar,Lambda,WelfareH,WelfareL,dumst);
Init = Init(Init.dumst==0,:);

Init = varfun(@mean,Init,"InputVariables",{'ImH','ImL','EmH','EmL','Lambda','Hri','Hni','WelfareH','WelfareL','Lih','Lil','Nih','Nil'},"GroupingVariables",{'i','o_iso'});

Init = renamevars(Init,["mean_ImH","mean_ImL","mean_EmH","mean_EmL","mean_Lambda","mean_Hri","mean_Hni","mean_WelfareH","mean_WelfareL","mean_Lih","mean_Lil","mean_Nih","mean_Nil"] ...
                        ,["ImH","ImL","EmH","EmL","Lambda","Hri","Hni","WelfareH","WelfareL","Lih","Lil","Nih","Nil"]);

 warning('off','MATLAB:xlswrite:AddSheet');
 writetable(Init,'U:\CHANGOM\JODE\Matlab_code\Replication_file_BCDM2024\STATA\Data\JODE_calib_output.xlsx','Sheet',1);
 e = actxserver('Excel.Application');  
 ewb = e.Workbooks.Open('U:\CHANGOM\JODE\Matlab_code\Replication_file_BCDM2024\STATA\Data\JODE_calib_output.xlsx');  
 ewb.Worksheets.Item(1).Name = 'Initial';  
 ewb.Save
 ewb.Close(false)
 e.Quit
 
 
 